@@ -1,3 +1,5 @@
+#include <sys/types.h>
+#include <unistd.h>
 #include <stdio.h>
 #include <string.h>
 #include "lutil.h"
@@ -16,6 +18,17 @@ char *stype;
 {
 	int st,rc;
 	node *nlent;
+	char *p, *q;
+
+	p = ttyname(0);
+
+	if (p)
+	{
+		q = strrchr(ttyname(0), '/');
+		if (q)
+			p = q + 1;
+		setnamesfx(p);
+	}
 
 	if ((nlent=getnlent(NULL)) == NULL)
 	{
@@ -35,6 +48,8 @@ char *stype;
 		st=SESSION_YOOHOO;
 	else if (strncmp(stype,"**EMSI_",7) == 0)
 		st=SESSION_EMSI;
+	else if (strcmp(stype,"binkp") == 0)
+		st=SESSION_BINKP;
 	else
 		st=SESSION_UNKNOWN;
 	debug(10,"answer to \"%s\" (%d) call",stype?stype:"unknown type",st);
