@@ -44,8 +44,13 @@ int aftercall(nlent)
 node *nlent;
 {
 	debug(18,"reading link stat (aftercall)");
-	chat(nlent,modemaftercall,NULL,NULL,0,NULL);
-	sleep(1);
+	if (modemaftercall==NULL)
+		debug(18,"no aftercall string");
+	else
+	{
+		chat(nlent,modemaftercall,NULL,NULL,0,NULL);
+		sleep(1);
+	}
 	return 0;
 }
 
