@@ -11,7 +11,8 @@ typedef struct _area_list {
 #endif
 
 extern int group_count;
-extern area_list *areas(char *);
+/* if int=1 return expanded areas from default, if int=0 does not */ 
+extern area_list *areas(char *,int);
 extern void ngdist(char*,char**,char**,char**,int*);
 #ifdef JE
 extern void areacharset(char*,int*,int*);
