@@ -96,8 +96,8 @@ char *strkconv(const char *src, int incode, int outcode)
 	}
   }
 
-  if(dest)
-	free(dest);
+/* if(dest)
+	free(dest); */
 /* FIXME: should be 
  * dest = (char *)malloc((strlen(src) + 1) + (6 * "number of \n + 1"));
  */
@@ -131,14 +131,16 @@ void kconv(char *in, char **out, int incode, int outcode)
         break;
       case CHRS_CP437 :
         switch (outcode) {
-          case CHRS_ISO_8859_1 : eight2eight(in,out,CP437__ISO_8859_1); break;
+          case CHRS_ISO_8859_1 :
+          case CHRS_ISO_8859_15: eight2eight(in,out,CP437__ISO_8859_1); break;
           case CHRS_MACINTOSH :	 eight2eight(in,out,CP437__MACINTOSH); break;
           default : 		 noconv(in,out); break;
         }
         break;
       case CHRS_CP850 :
         switch (outcode) {
-          case CHRS_ISO_8859_1 : eight2eight(in,out,CP850__ISO_8859_1); break;
+          case CHRS_ISO_8859_1 :
+          case CHRS_ISO_8859_15: eight2eight(in,out,CP850__ISO_8859_1); break;
           case CHRS_MACINTOSH :  eight2eight(in,out,CP850__MACINTOSH); break;
           default :              noconv(in,out); break;
         }
@@ -205,19 +207,22 @@ void kconv(char *in, char **out, int incode, int outcode)
         }
       case CHRS_ISO_11 :
         switch (outcode) {
-          case CHRS_ISO_8859_1 : eight2eight(in,out,ISO_11__ISO_8859_1); break;
+          case CHRS_ISO_8859_1 :
+          case CHRS_ISO_8859_15: eight2eight(in,out,ISO_11__ISO_8859_1); break;
           default :		 noconv(in,out); break;
         }
         break;
       case CHRS_ISO_4 :
         switch (outcode) {
-          case CHRS_ISO_8859_1 : eight2eight(in,out,ISO_4__ISO_8859_1); break;
+          case CHRS_ISO_8859_1 :
+          case CHRS_ISO_8859_15: eight2eight(in,out,ISO_4__ISO_8859_1); break;
           default :		 noconv(in,out); break;
         }
         break;
       case CHRS_ISO_60 :
         switch (outcode) {
-          case CHRS_ISO_8859_1 : eight2eight(in,out,ISO_60__ISO_8859_1); break;
+          case CHRS_ISO_8859_1 :
+          case CHRS_ISO_8859_15: eight2eight(in,out,ISO_60__ISO_8859_1); break;
           default :		 noconv(in,out); break;
         }
         break;
@@ -246,11 +251,14 @@ void kconv(char *in, char **out, int incode, int outcode)
         }
         break;
       case CHRS_ISO_8859_1 :
+      case CHRS_ISO_8859_15:
         switch (outcode) {
-	  case CHRS_CP437 :	eight2eight(in,out,ISO_8859_1__CP437); break;
-	  case CHRS_CP850 :	eight2eight(in,out,ISO_8859_1__CP850); break;
-          case CHRS_MACINTOSH : eight2eight(in,out,ISO_8859_1__MACINTOSH); break;
-          default :		noconv(in,out); break;
+	  case CHRS_CP437 :	 eight2eight(in,out,ISO_8859_1__CP437); break;
+	  case CHRS_CP850 :	 eight2eight(in,out,ISO_8859_1__CP850); break;
+          case CHRS_MACINTOSH :  eight2eight(in,out,ISO_8859_1__MACINTOSH); break;
+          case CHRS_ISO_8859_1 :
+          case CHRS_ISO_8859_15: noconv(in,out); break;
+          default :		 noconv(in,out); break;
         }
         break;
       case CHRS_ISO_8859_2 :
@@ -325,7 +333,8 @@ void kconv(char *in, char **out, int incode, int outcode)
         switch (outcode) {
           case CHRS_CP437 :	 eight2eight(in,out,MACINTOSH__CP437); break;
 	  case CHRS_CP850 :	 eight2eight(in,out,MACINTOSH__CP850); break;
-          case CHRS_ISO_8859_1 : eight2eight(in,out,MACINTOSH__ISO_8859_1); break;
+          case CHRS_ISO_8859_1 :
+          case CHRS_ISO_8859_15: eight2eight(in,out,MACINTOSH__ISO_8859_1); break;
           default :		 noconv(in,out); break;
         }
         break;
@@ -355,6 +364,11 @@ void kconv(char *in, char **out, int incode, int outcode)
           default :		  noconv(in,out); break;
         }
         break;
+      case CHRS_UTF_7 :		utf7_to_eight(in,out,&outcode);
+        break;
+      case CHRS_UTF_8 :		utf8_to_eight(in,out,&outcode);
+	break;
+
       case CHRS_ZW :
         switch (outcode) {
           case CHRS_HZ :	zw2hz(in,out); break;
@@ -609,11 +623,14 @@ int incode, outcode;
 	iptr = s;
 	while (*iptr) {
 		if (!strncmp(iptr,"=?",2)) {
-			incode=getcode(iptr+2);
-			if (incode==CHRS_NOTSET) return s;
 			q=strchr(iptr+2,'?');
-			if (q) iptr=q;
-			else return s;
+			if (q) {
+				incode=getcode(iptr+2);
+				if (incode==CHRS_NOTSET) return s;
+				iptr=q;
+			} else {
+				return s;
+			}
 			if (!strncasecmp(iptr,"?Q?",3)) {
 				codage = QCODAGE;
 				iptr+=3;
