@@ -97,7 +97,7 @@ faddr *bestaka;
 		if (mode==1) {
 			sprintf(buf,"<MSGID_%s@fidonet.org>",
 				qp_encode(msgid,1));
-			*r='\n';
+			if (r) *r='\n';
 			return buf;
 		} else {
 #endif
@@ -113,7 +113,7 @@ faddr *bestaka;
 		if (mode==1) {
 			sprintf(buf,"<MSGID_%s@fidonet.org>",
 				qp_encode(msgid,1));
-			*r='\n';
+			if (r) *r='\n';
 			return buf;
 		} else {
 #endif
@@ -616,22 +616,30 @@ rfcmsg *kmsg;
 		if ((p=hdr("Newsgroups",msg)))
 /* The gate at puddle.fidonet.org put spaces in Newsgroups header */
 		{
-		if ((strstr(p,", ")))
+			if ((strstr(p,", ")))
 			{
-			while ((r = strchr(p, ' ')))
+				while ((r = strchr(p, ' ')))
                 	        {
 					*r = '\0';
 					strcat(p,r+1);
                 	        }
-			fprintf(pip,"Newsgroups: %s",p);
 			}
-		else fprintf(pip,"Newsgroups:%s",p);
 		}
 #else
-		if ((p=hdr("Newsgroups",msg))) fprintf(pip,"Newsgroups:%s",p);
+		p=hdr("Newsgroups",msg);
 #endif
-		else if ((p=hdr("RFC-Newsgroups",kmsg))) fprintf(pip,"Newsgroups: %s",p);
-		else if ((p=hdr("Newsgroups",kmsg))) fprintf(pip,"Newsgroups: %s",p);
+		if (p == NULL) p=hdr("RFC-Newsgroups",kmsg);
+		if (p == NULL) p=hdr("Newsgroups",kmsg);
+		if (p)
+		{
+			while (*p && isspace(*p)) p++;
+			if ((areas(p,0))) {
+				fprintf(pip,"Newsgroups: %s",p);
+			} else {
+				fprintf(pip,"Newsgroups: %s\n",newsgroup);
+				fprintf(pip,"X-Origin-Newsgroups: %s",p);
+			}
+		}
 		else fprintf(pip,"Newsgroups: %s\n",newsgroup);
 
 		if ((p=hdr("Distribution",msg))) fprintf(pip,"Distribution:%s",p);
