@@ -15,6 +15,9 @@
 #include <sys/types.h>
 #include <sys/stat.h>
 #include <time.h>
+#ifdef HAVE_LOCALE_H
+#include <locale.h>
+#endif
 #include "xutil.h"
 #include "lutil.h"
 #include "ftn.h"
@@ -544,6 +547,14 @@ char *addr,*nm;
 		memset(tmp,0,sizeof(faddr));
 	}
 
+	/* check for "" (that is a NULL name, it is used to specify
+	 * NULL passwords)
+	 */
+	if (nm && (*nm == '\"')) {
+		if ((strlen(nm)==2) && (*(nm+1) == '\"'))
+			*nm='\0';
+	}
+
 	for (tmpl=lst;*tmpl;tmpl=&((*tmpl)->next));
 	*tmpl=(fa_list*)xmalloc(sizeof(fa_list));
 	(*tmpl)->next=NULL;
