@@ -1,91 +1,36 @@
-#!/usr/bin/perl
+#!/usr/bin/perl  
+use Sys::Syslog;
+ 
+# run syslogd with -r if you want it to work.
+# locate Syslog.pm and if it doesn't exist, read the manpage for h2ph.
+#
+# bug: crashes in line ~300 if system does not appear in newsfeeds
+# but has areafix password. 
+#
+# bug: run this as root, or it will zero your newsfeeds file.
 
 #
-# $Id: areafix.pl,v 1.2 1997/04/19 13:23:31 fnet Exp fnet $
+# Revision 1.3 1998/08/01 18:03:41 fnet
+# Fixed for perl5. James Vahn 1:346/3 <jvahn@short.circuit.com>
 #
-# $Log: areafix.pl,v $
 # Revision 1.2  1997/04/19 13:23:31  fnet
 # gup3w-compatible locking added
 #
 # Revision 1.1  1997/04/09 13:52:10  fnet
 # Initial revision
 #
-#
 
-$VERSION="0.5.07";
+
+# $VERSION = "0.5.07-jv12";
 
 ## Type _full_ path below
 
-$CONFIGFILE="/staff/fnet/areafix/areafix/config/config";
+$CONFIGFILE="/usr/lib/ifmail/areafix/config";
 $CONFIGFILE=$ARGV[0] if defined($ARGV[0]);
 
 ## main program :)
-&areafix();
 
-##   
-#
-# $CONFIGFILE -      .
-#
-# ,   
-# $NO_FIDO	     -   Areas
-# $SYSOP_NAME        -   
-# $ROBOT_NAME        -      
-# $ADDRESS           -  
-# $UPLINK_ROBOT_NAME -     (    )
-# $UPLINK_ADDRESS    -  
-# $UPLINK_PASSWORD   -   Area Manager  
-# $QUEUE	     -     
-# $ECHO2NEWS         -   ifmail's areas file
-# $HELPFILE          -     
-# $ACTIVE            - $NEWSLIB/active
-# $NEWSGROUPS        - $NEWSLIB/newsgroups
-# $NEWSFEEDS         - $NEWSLIB/newsfeeds
-# $PASSIVE_NEWSFEEDS - ,        %PASSIVE
-# $NEWSLOCK	     - $LOCKS
-# $RESTFILE          -      "" 
-# $MAILCOMMAND       - ,   ( |/usr/sbin/sendmail -t )
-# $OUTNEWSFEEDS      -   "  newsfeeds" -- 
-#                        $NEWSFEEDS
-# $DESCRMISSING      - ""  ,    $NEWSLIB/newsgroups
-# $RELOADCOMMAND     -    newsfeeds
-# $UPLINK_PASSWORD   -    
-# $FORWARD           -    
-# $LOG_FACILITY	     - log facility  syslogd (. syslog(2))
-# $LOG_LEVEL	     -   
-# $XCOM_TABLE	     -   
-# $SEMAPHORE	     -  (   :)
-#
-##      
-#
-# $HELP =     p
-# %passwds - p   $passwds{"hostname"}
-# %feeds   -   ()  newsfeeds $feeds{"hostname"}
-# %passive -     .
-# %description  -  . ($description{$newsgroup})
-# @restricted[$i] -  ,   .
-# @sites[$i] -   (i - )
-# @exclude{$sites[i]} -  exclude-
-# @patterns{$sites[i]} -  p
-# @distribs{$sites[i]} -  distributions
-# @flags{$sites[i]} - 
-# @params{$sites[i]} - pp
-# @comments{$sites[i]} - p _p_  
-# $lastcomment - p   
-# %echo2ng - p    p $echo2ns{"newsgroup_name"}
-# %ng2echo - p
-# $active[$i] - newsgroup
-#
-##    :
-#
-# $USERADDR - full address (user@host)
-# $USERNAME - username part
-# $USERHOST - host part ( $USERADDR eq "$USERNAME@$USERHOST")
-# $SUBJECT  - letter's subject
-# $FROM     - From field
-# $REPLYTO  - Reply-To field
-#
-## other:
-# $NEWSFEEDSCHANGED (==1    add/delete)
+&areafix();
 
 sub areafix
 {
@@ -150,8 +95,8 @@ sub process_message
     &parse_header() || return 0;
     open(OUT,$MAILCOMMAND) || die &log('err',"Bad mailing command $MAILCOMMAND",0);
     &log('info',"Processing message from $USERADDR",1);
-    print OUT "From: $ROBOT_NAME@$ADDRESS\n";
-    print OUT "To: ".(defined($REPLYTO)?$REPLYTO:$USERADDR)."\n";
+    print OUT "From: $ROBOT_NAME \<$ROBOT_NAME\@$ADDRESS\>\n";
+    print OUT "To: Sysop \<".(defined($REPLYTO)?$REPLYTO:$USERADDR)."\>\n";
     print OUT "Subject: Reply from Area Manager\n\n";
 
     if ( &newsfeeds_check($USERHOST) )
@@ -177,11 +122,11 @@ sub process_message
 }
 
 sub startup
+
 { 
     &read_config($CONFIGFILE) || die "Bad configuration file";
-    require "syslog.pl";
     &openlog('areafix','cons,pid',$LOG_FACILITY);
-    &log('debug','Firing up',3);
+    ##&log('info','Starting areafix',3);
 }
 
 sub finish
@@ -203,7 +148,7 @@ sub finish
     }
     close(IN);
     close(FORWARD) if ($DOING_FORWARD);
-    &log('debug',"Shutting down",3);
+    ##&log('info','stopping areafix');
     &closelog();
 }
 
@@ -257,12 +202,9 @@ sub log
 
 sub write_password_flame
 {
-    print OUT "\nDear ".&torealname($USERNAME)."!\n\n";
-    print OUT "You gave incorrect password for Area Manager, so,\n";
-    print OUT "your AreaFix query will be refused. Please repeat\n";
-    print OUT "your request with correct password or contact\n";
-    print OUT "with ".&torealname($SYSOP_NAME).", our system operator.\n\n";
-    print OUT "\t\t Yours, AreaFix of $ADDRESS\n";
+    print OUT "Your areafix password can't be found and the request\n";
+    print OUT "has been refused. Perhaps you didn't use the correct\n";
+    print OUT "password, please try again.\n";
     &log('notice',"Remote $USERADDR gave incorrect password $SUBJECT",1);
 }
 
@@ -274,13 +216,9 @@ sub write_restricted_flame
 
 sub write_address_flame
 {
-    print OUT "\nDear ".&torealname($USERNAME)."!\n\n";
-    print OUT "I'm terribly sorry, but your site is not present\n";
-    print OUT "in our newsfeeds file, so, you can not access\n";
-    print OUT "Area Manager on this node. Please, contact with\n";
-    print OUT &torealname($SYSOP_NAME).", our system operator.\n\n";
-    print OUT "\t\t Yours, AreaFix of $ADDRESS\n";
-    &log('notice',"Site $USERHOST was not found in newsfeeds",1);
+    print OUT "Your site isn't configured for areafix here and\n";
+    print OUT "the request has been refused.\n";
+    &log('notice',"Site $USERHOST was not found in passwords/newsfeeds",1);
 }
 
 sub process_message_body
@@ -322,13 +260,17 @@ sub make_passive
     &log('debug',"Processing %PASSIVE operation",4);
     if ($passive{$SITE}==1)
     {
+	print OUT "-----------------------------------------------------\n";
         print OUT "%PASSIVE - your newsfeeds already have passive status\n";
+	print OUT "-----------------------------------------------------\n";
     }
     else
     {
         $passive{$SITE}=1;
         $NEWSFEEDSCHANGED=1;
+	print OUT "-------------------------------------------------\n";
         print OUT "%PASSIVE - your newsfeeds have passive status now\n";
+	print OUT "-------------------------------------------------\n";
     }
 }
 
@@ -337,13 +279,17 @@ sub make_active
     &log('debug',"Processing %ACTIVE operation",4);
     if ($passive{$SITE}==0)
     {
+	print OUT "----------------------------------------------------\n";
         print OUT "%ACTIVE - your news feeds already have active status\n";
+	print OUT "----------------------------------------------------\n";
     }
     else
     {
         $passive{$SITE}=0;
         $NEWSFEEDSCHANGED=1;
+	print OUT "------------------------------------------------\n";
         print OUT "%ACTIVE - your news feeds have active status now\n";
+	print OUT "------------------------------------------------\n";
     }
 }
 
@@ -405,7 +351,7 @@ sub subscribe
         &log('notice',"Can not subscribe to $_[0] - no such echo",1);
         if ($FORWARD)
         {    
-            print OUT " Your request will be forwarded to our uplink. Try later.\n";
+            print OUT "Your request will be forwarded to our uplink. Try later.\n";
             &log('notice',"This request will be forwarded to our uplink",1);
             &forward($_[0]);
         }
@@ -488,8 +434,8 @@ sub forward
     {
 	open(FORWARD,$MAILCOMMAND) || (&log('err',"Bad mailing command $MAILCOMMAND",0),return);
 	$SYSOP_NAME=~tr/[_ ]/./;
-	print FORWARD "From: $SYSOP_NAME@$ADDRESS\n";
-	print FORWARD "To: $UPLINK_ROBOT_NAME@$UPLINK_ADDRESS\n";
+	print FORWARD "From: $SYSOP_NAME \<$SYSOP_NAME\@$ADDRESS\>\n";
+	print FORWARD "To: $UPLINK_ROBOT_NAME \<$UPLINK_ROBOT_NAME\@$UPLINK_ADDRESS\>\n";
 	print FORWARD "Subject: $UPLINK_PASSWORD\n\n";
 	$DOING_FORWARD=1;
     }	
@@ -526,8 +472,8 @@ sub unsubscribe
 
     unless ($unsubscribed)
     {
-        print OUT "-$_[0] -- No match in your subscription list\n";
-        &log('debug',"Remote is not subsribed to $_[0]",5);
+        print OUT "-$_[0] -- No match in your subscription list.\n";
+        &log('debug',"Remote is not subscribed to $_[0]",5);
     }
     else
     {
@@ -577,7 +523,11 @@ sub print_list
 {
     local($echo,$group,$descr,$oldfh);
     &log('debug',"Processing %LIST operation",4);
-    print OUT "\%LIST\n";
+    print OUT "--------------------------------------------------------\n";
+    print OUT "These are the echos currently available on this node.\n";
+    print OUT "To get a complete list please send a file request for\n"; 
+    print OUT "'backbone.na'. New requests will be forwarded.\n";
+    print OUT "--------------------------------------------------------\n";
     $oldfh=select(OUT);
     $~=$NO_FIDO?NO_FIDO:($WIDE?OUTWIDE:OUT);
     foreach $group (sort($IS_FTN_LINK?values(%echo2ng):@active))
@@ -605,35 +555,45 @@ sub print_invalid
 
 sub print_help 
 {
-    print OUT "%HELP\n$HELP\n";
+    print OUT "--------------------------------------\n";
+    print OUT "In response to your request for %HELP\n";
+    print OUT "--------------------------------------\n";
+    print OUT "$HELP\n";
 }
 
 format OUTWIDE=
-@<<<<<<<<<<<<<<<<<<<<<<<<< @<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<< @<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<
+@<<<<<<<<<<<<<<<<<< @<<<<<<<<<<<<<<<<<<<<<< @<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<
 $echo,      $group,       $descr
 .
 ;
 format OUT=
-@<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<< @<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<
-$echo,           $descr
+@<<<<<<<<<<<<<<<<<<<<< @<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<
+$echo,	$descr
 .
 format NO_FIDO=
-@<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<< @<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<
-$group,				    $descr
+@<<<<<<<<<<<<<<<<<<<<<<<< @<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<<
+$group,	$descr
 .
 
 sub print_query
 {
     local($echo,$group,$descr,$oldfh);
     &log('debug',"Processing %QUERY operation",4);
-    print OUT "\%QUERY\n";
+    print OUT "---------------------------\n";
+    print OUT "In response to your %QUERY \n";
+    print OUT "---------------------------\n";
     $oldfh=select(OUT);
     $~=$NO_FIDO?NO_FIDO:($WIDE?OUTWIDE:OUT);
     foreach $group (sort(keys(%patt_hash)))
     {
-        $echo=defined ($ng2echo{$group}) ? $ng2echo{$group}: "UNTRANSLATED";
-        $descr=defined( $description{$group})? $description{$group}:$DESCRMISSING;
-        write ;
+        ##$echo=defined ($ng2echo{$group}) ? $ng2echo{$group}: "UNTRANSLATED";
+	#$echo=defined ($ng2echo{$group}) ? $ng2echo{$group}: " ----??----";
+	#$descr=defined( $description{$group}) ? $description{$group}:$DESCRMISSING;
+	#if ($echo ne " ----??----") { write ; }
+	
+	$echo=$ng2echo{$group};
+	$descr=defined( $description{$group}) ? $description{$group}:$DESCRMISSING;
+	if ($echo) { write ; }
     }
     select($oldfh);
 }
@@ -642,7 +602,9 @@ sub print_unlinked
 {
     local($echo,$group,$descr,$oldfh);
     &log('debug',"Processing %UNLINKED operation",4);
-    print OUT "\%UNLINKED\n";
+    print OUT "-------------------------------------------\n";
+    print OUT "You are %UNLINKED from the following echos:\n";
+    print OUT "-------------------------------------------\n";
     $oldfh=select(OUT);
     $~=$NO_FIDO?NO_FIDO:($WIDE?OUTWIDE:OUT);
     
@@ -661,7 +623,7 @@ sub print_unlinked
 # ---- RFC822-header parsing
 # $USERADDR - full address (user@host)
 # $USERNAME - username part
-# $USERHOST - host part ( $USERADDR eq "$USERNAME@$USERHOST")
+# $USERHOST - host part ( $USERADDR eq "$USERNAME\@$USERHOST")
 # $SUBJECT  - letter's subject
 # $FROM     - From field
 # inputs from IN filehandle
@@ -687,6 +649,7 @@ sub parse_header
 	$REPLYTO=&parse_addr($value) if ($headline=~/^Reply-To$/io);
     }
     return 0 unless (defined($USERADDR) && defined($SUBJECT));
+    $USERNAME="";
     ($USERNAME,$USERHOST)=split("@",$USERADDR);
     return 1;
 }
@@ -698,60 +661,57 @@ sub write_newsfeeds
     local ($site,$groupstr,$outfile,$passive_outfile);
     $outfile=$_[0];
     $passive_outfile=$_[1];
-    open(outhandle,">".$outfile) || return 0;
-    open(passive_outhandle,">".$passive_outfile) || return 0;
-    foreach $site (@sites) #    !
+    open(OutHandle,">".$outfile) || return 0;
+    open(passive_OutHandle,">".$passive_outfile) || return 0;
+    foreach $site (@sites) 
     {
-	# ..  inn    - *, ... 
 	$patterns{$site}="!*" if ($patterns{$site} eq "");
         if ($passive{$site}==0)
         {
-            print outhandle $comments{$site}; #   
-            print outhandle $site; #  
-            print outhandle "/".$exclude{$site} unless($exclude{$site}eq""); #  ,  
-#     ,       .
-            print outhandle "\\\n"; #  \   .
-            $groupstr=$patterns{$site}; #     ,
-            $groupstr=~s|,|,\\\n\t|go; #       
-            print outhandle "\t:$groupstr\\\n"; #     newsfeeds
-            print outhandle ("\t/".$distribs{$site}."\\\n") unless($distribs{$site} eq ""); #    ,    ...
-            print outhandle "\t:";
-            print outhandle ($flags{$site}) unless ($flags{$site} eq ""); # ...   ...
-            print outhandle ":";
-            print outhandle $params{$site} unless ($params{$site}eq ""); # ...  .
-            print outhandle "\n";
+            print OutHandle $comments{$site}; 
+            print OutHandle $site; 
+            print OutHandle "/".$exclude{$site} unless($exclude{$site}eq""); 
+            print OutHandle "\\\n"; 
+            $groupstr=$patterns{$site};
+            $groupstr=~s|,|,\\\n\t|go; 
+            print OutHandle "\t:$groupstr\\\n";
+            print OutHandle ("\t/".$distribs{$site}."\\\n") unless($distribs{$site} eq ""); 
+            print OutHandle "\t:";
+            print OutHandle ($flags{$site}) unless ($flags{$site} eq ""); 
+            print OutHandle ":";
+            print OutHandle $params{$site} unless ($params{$site}eq ""); 
+            print OutHandle "\n";
         }
         else
         {
-            print passive_outhandle $comments{$site}; #   
-            print outhandle $comments{$site}; #   
-            print passive_outhandle $site; #  
-            print outhandle $site; #  
-            print passive_outhandle "/".$exclude{$site} unless($exclude{$site}eq""); #  ,  
-            print outhandle "/".$exclude{$site} unless($exclude{$site}eq""); #  ,  
-#     ,       .
-            print passive_outhandle "\\\n"; #  \   .
-            print outhandle "\\\n"; #  \   .
-            $groupstr=$patterns{$site}; #     ,
-            $groupstr=~s|,|,\\\n\t|go; #       
-            print passive_outhandle "\t:$groupstr\\\n"; #     passive newsfeeds
-            print outhandle "\t:!*\\\n"; #   !*  newsfeeds
-            print passive_outhandle ("\t/".$distribs{$site}."\\\n") unless($distribs{$site} eq ""); #    ,    ...
-            print passive_outhandle "\t:";
-            print outhandle "\t:";
-            print passive_outhandle ($flags{$site}) unless ($flags{$site} eq ""); # ...   ...
-            print passive_outhandle ":";
-            print passive_outhandle $params{$site} unless ($params{$site}eq ""); # ...  .
-            print passive_outhandle "\n";
-            print outhandle ($flags{$site}) unless ($flags{$site} eq ""); # ...   ...
-            print outhandle ":";
-            print outhandle $params{$site} unless ($params{$site}eq ""); # ...  .
-            print outhandle "\n";
+            print passive_OutHandle $comments{$site}; 
+            print OutHandle $comments{$site}; 
+            print passive_OutHandle $site; 
+            print OutHandle $site; 
+            print passive_OutHandle "/".$exclude{$site} unless($exclude{$site}eq""); 
+            print OutHandle "/".$exclude{$site} unless($exclude{$site}eq""); 
+            print passive_OutHandle "\\\n"; 
+            print OutHandle "\\\n"; 
+            $groupstr=$patterns{$site}; 
+            $groupstr=~s|,|,\\\n\t|go; 
+            print passive_OutHandle "\t:$groupstr\\\n"; 
+            print OutHandle "\t:!*\\\n"; 
+            print passive_OutHandle ("\t/".$distribs{$site}."\\\n") unless($distribs{$site} eq ""); 
+            print passive_OutHandle "\t:";
+            print OutHandle "\t:";
+            print passive_OutHandle ($flags{$site}) unless ($flags{$site} eq ""); 
+            print passive_OutHandle ":";
+            print passive_OutHandle $params{$site} unless ($params{$site}eq ""); 
+            print passive_OutHandle "\n";
+            print OutHandle ($flags{$site}) unless ($flags{$site} eq ""); 
+            print OutHandle ":";
+            print OutHandle $params{$site} unless ($params{$site}eq "");
+            print OutHandle "\n";
         }
     }
-    print outhandle $last_comment; #     .
-    close(outhandle);
-    close(passive_outhandle);
+    print OutHandle $last_comment;
+    close(OutHandle);
+    close(passive_OutHandle);
     return 1;
 }
 
@@ -771,60 +731,37 @@ sub read_control_files
     $WIDE=0;
 }
 
-## ---------------- passwd.pl --------------------
-#  passwd
-# %passwds - p   $passwds{"hostname"}
-# %feeds -   ()  newsfeeds $feeds{"hostname"}
-#
-
 sub read_passwd {
     local($pwd_file,$host,$feed,$passwd);
     $pwd_file=$_[0];
-    open(pwd_handle,$pwd_file) || die &log('err',"Cannot open $pwd_file",0);
+    open(pwd_Handle,$pwd_file) || die &log('err',"Cannot open $pwd_file",0);
 
-    while(<pwd_handle>) {
+    while(<pwd_Handle>) {
 	chop;
         next if (/\s+#/o);
         next unless(($host,$feed,$passwd)=/([^:]+):([^:]+):([^:]+)/o);
         $passwds{$host}=$passwd;
         $feeds{$host}=$feed;
     }
-    close(pwd_handle);
+    close(pwd_Handle);
     return 1;
 }
 
-## ----------- newsgrou.pl -----------------
-#   newsgroups  
-# %description  -  . ($description{$newsgroup})
-
 sub read_newsgroups
 {
     local($ng_file);
     $ng_file=$_[0];
-    open(ng_handle,$ng_file) || die &log('err',"Cannot open $ng_file",0);
+    open(ng_Handle,$ng_file) || die &log('err',"Cannot open $ng_file",0);
 
-    while(<ng_handle>){
+    while(<ng_Handle>){
         next if(/^\s*#/o);
         next unless(($group,$descr)=/^(\S+)\s+(.*)\s*$/o);
         $description{$group}=$descr;
     }
-    close(ng_handle);
+    close(ng_Handle);
     return 1;
 }
 
-## ------------------ newsfeed.pl -----------------
-# newsfeeds parser
-#        newsfeeds,
-# p    :
-# @sites[$i] -   (i - )
-# @exclude{$sites[i]} -  exclude-
-# @patterns{$sites[i]} -  p
-# @distribs{$sites[i]} -  distributions
-# @flags{$sites[i]} - 
-# @params{$sites[i]} - pp
-# @comments{$sites[i]} - p _p_  
-# $lastcomment - p   
-
 sub read_newsfeeds
 {
     local($current_line,$temp_line,$commentstr,@newsfeeds);
@@ -833,53 +770,37 @@ sub read_newsfeeds
     $nf_file=$_[0];
     $index=0;
     $commentstr="";
-    open(handle,$nf_file) || die &log('err',"Cannot open $nf_file",0);
-    push(@newsfeeds,$_) while <handle>;
-    close(handle); #         newsfeeds !
+    open(Handle,$nf_file) || die &log('err',"Cannot open $nf_file",0);
+    push(@newsfeeds,$_) while <Handle>;
+    close(Handle); 
 
 input:
     while($_=shift(@newsfeeds))
     {
-        next input if /^$/o; #    newsfeeds .
+        next input if /^$/o; 
 
-##     newsfeeds ...
-
-        $current_line=$_; #   .
-        if($current_line=~m/^\s*#/o) #    - ,
-# ..       - 
-#  ( # ), 
+        $current_line=$_; 
+        if($current_line=~m/^\s*#/o) 
         {
-            $commentstr.=$current_line; #     
-            next input; #      !
+            $commentstr.=$current_line; 
+            next input; 
         }
 
-##   -   ...
-
         chop($current_line); ##MSDOS
 
-##  :   newsfeeds   site, -
-## , ,     (   ,
-##    C,  \  ""  )   ...
-
-        while ($current_line=~/\\$/o ) # ,     ...
+        while ($current_line=~/\\$/o ) 
         {
-            chop($current_line); #  \   ...
-            chop($temp_line=shift(@newsfeeds)); #  ,  \n ...
-            $temp_line=~s/^\s*//o; #    ...
-            $current_line .= $temp_line; #     ,   .
+            chop($current_line);
+            chop($temp_line=shift(@newsfeeds)); 
+            $temp_line=~s/^\s*//o; 
+            $current_line .= $temp_line;
         }
         $sitestr=$current_line;
 
-##         site     -
-## : <site>:<feeds>:<flags>:<parameters> ...
-
-        ($sitetmp,$patstmp, $flgs, $param)=split(/:/,$sitestr); #        !
-        $site=$sitetmp; # $site -  .
-        $pats=$patstmp; # $pats -  .
-        $excl=""; # $excl -    ,       ...
-
-##       ,  ,   
-##    ...
+        ($sitetmp,$patstmp, $flgs, $param)=split(/:/,$sitestr); 
+        $site=$sitetmp;
+        $pats=$patstmp;
+        $excl="";
 
         if ($sitetmp=~m|([^/]+)/([^/]+)|o)
         {
@@ -887,9 +808,7 @@ input:
             $excl=$2;
         }
 
-        $distr=""; # $distr -   newsgroup distribution
-
-##          .
+        $distr=""; 
 
         if($patstmp=~m|([^/]+)/([^/]+)|o)
         {
@@ -899,33 +818,32 @@ input:
 
 	$pats="" if ($pats eq "!*");
 
-##      : 
-
-        $sites[$index]=$site; #   ->    ...
+        $sites[$index]=$site; 
         $passive{$site}=0;
-        $exclude{$site}=$excl; #  ->    ...
-        $patterns{$site}=$pats; #  ...
-        $distribs{$site}=$distr; #  ...
-        $flags{$site}=$flgs; #  ...
-        $params{$site}=$param; #  ...
-        $comments{$site}=$commentstr; #  ...
-        $index++; #     1 ...
-        $commentstr=""; #     ...
+        $exclude{$site}=$excl;
+        $patterns{$site}=$pats;
+        $distribs{$site}=$distr;
+        $flags{$site}=$flgs;
+        $params{$site}=$param;
+        $comments{$site}=$commentstr;
+        $index++;
+        $commentstr="";
     }
-    $last_comment=$commentstr; #       .
+    $last_comment=$commentstr;
     return 1;
 }
 
 sub read_passive_newsfeeds
 {
+    $counter="";
     local($current_line,$temp_line,$commentstr);
     local($nf_file,$site,$sitetmp,$index);
     local($excl,$pats,$patstmp,$distr,$flgs,$param,$counter);
     $nf_file=$_[0];
     $commentstr="";
-    open(handle,$nf_file) || die &log('err',"Cannot open $nf_file",0);
+    open(Handle,$nf_file) || die &log('err',"Cannot open $nf_file",0);
 input:
-    while(<handle>)
+    while(<Handle>)
     {
         next input if /^$/o;
         $current_line=$_;
@@ -938,7 +856,7 @@ input:
         while ($current_line=~/\\$/o)
         {
             chop($current_line);
-            chop($temp_line=<handle>);
+            chop($temp_line=<Handle>);
             $temp_line=~s/^\s*//o;
 
             $current_line.=$temp_line;
@@ -970,37 +888,28 @@ input:
         $comments{$site}=$commentstr;
         $commentstr="";
     }
-    close(handle);
+    close(Handle);
     return 1;
 }
 
-## ----------------   read help file --------------
-#  HELP'
-# $HELP =     p
-#
 sub read_help
 {
     local($helpf);
     $helpf=$_[0];
-    open(hh,$helpf) || die &log('err',"Cannot open $helpf",0);
+    open(HH,$helpf) || die &log('err',"Cannot open $helpf",0);
     $HELP="";
-    $HELP.=$_ while(<hh>);
-    close(hh);
+    $HELP.=$_ while(<HH>);
+    close(HH);
     return 1;
 }
 
-## ------------ read areas file ------------------
-#  :
-# %echo2ng - p    p $echo2ns{"newsgroup_name"}
-# %ng2echo - p
-
 sub read_areas
 {
     local($areas_file,$echo,$ngroup);
     $areas_file=$_[0];
-    open(areas_handle,$areas_file) || die &log('err',"Cannot open $areas_file",0);
+    open(areas_Handle,$areas_file) || die &log('err',"Cannot open $areas_file",0);
 
-    while(<areas_handle>)
+    while(<areas_Handle>)
     {
         next if (/^\s*#/o);
         next unless(($echo,$ngroup)=/(\S+)\s+(\S+)/o);
@@ -1010,7 +919,7 @@ sub read_areas
         $echo2ng{$echo}=$ngroup;
         $ng2echo{$ngroup}=$echo;
     }
-    close(areas_handle);
+    close(areas_Handle);
     return 1;
 }
 
@@ -1021,33 +930,26 @@ sub findinactive
     return grep(/^$tmp$/,@active);
 }
 
-## --------- read active file -----------------------
-#  :
-# $active[$i]
-# 
 sub read_active
 {
     local($active_file,$ngroup);
     $active_file=$_[0];
-    open(active_handle,$active_file) || die &log('err',"Cannot open $active_file",0);
-    while(<active_handle>)
+    open(active_Handle,$active_file) || die &log('err',"Cannot open $active_file",0);
+    while(<active_Handle>)
     {
         next if (/^\s*#/o);
         next unless(($ngroup)=/^(\S+)/o);
         push(@active,$ngroup);
     }
-    close(active_handle);
+    close(active_Handle);
     return 1;
 }
 
-## --------- read restricted file -----------------------
-#  :
-# $restricted[$i]
 sub read_restricted
 {
     local($echo,$addrpatt);
-    open(handle,$_[0]) || die &log('err',"Cannot open $_[0]",0);
-    while(<handle>)
+    open(Handle,$_[0]) || die &log('err',"Cannot open $_[0]",0);
+    while(<Handle>)
     {
         next if (/^\s*#/o);
         if (/^(\S+)\s+(\S+)/o)
@@ -1068,7 +970,7 @@ sub read_restricted
 	&wildmat_to_regexp($addrpatt);
         $restricted{$echo}=$addrpatt;
     }
-    close(handle);
+    close(Handle);
     return 1;
 }
 
@@ -1076,8 +978,8 @@ sub read_config
 {
     local($config_file);
     $config_file=$_[0];
-    open(handle,$config_file) || die "Cannot open $config_file";
-    while(<handle>)
+    open(Handle,$config_file) || die "Cannot open $config_file";
+    while(<Handle>)
     {
         next if (/^\s*#/o);
         next unless(($keyword,$val)=/^(\S+)\s+(.*)\s*$/o);
@@ -1127,16 +1029,13 @@ sub read_config
 	&& defined($SEMAPHORE)
 	&& defined($LOG_FACILITY)); 
 }
-##--------  end of reading of config files
-#
-##-------- shlock/shunlock
 
 sub shlock
 {
 	local($file,$try)=@_;
 	local($pid,$n,$rc);
 
-	open(F,">$file.$$") || die "Cannot open temp lock file: $!";
+	open(F,">$file.$$") || die "Cannot open $file.$$\n$!";
 	print F $$;
 	close F;
 
