@@ -14,6 +14,7 @@ areafix: |"/usr/lib/ifmail/areafix/areaqueue /var/spool/ifmail/aqueue"
 #include <stdio.h>
 #include <sys/types.h>
 #include <sys/stat.h>
+#include <time.h>
 
 int main(int argc,char **argv)
 {
@@ -27,6 +28,7 @@ sprintf(s1,"%s/%s",argv[1],"tmp");
 mkdir(s1,0700);
 sprintf(s1,"%s/%s",s1,name);
 sprintf(s2,"%s/%s",argv[1],name);
+umask(007);
 if ((f=fopen(s1,"w"))==NULL) return 2;
 while ((c=getchar())!=EOF)
 	putc(c,f);	
